menu
bluetooth_pos_printer_utils package
documentation
core/halftone.dart
Halftone class
Halftone class
dark_mode
light_mode
Halftone
class
Constructors
Halftone
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Static Methods
applyFloydSteinberg
(
Image
image
)
→ Image
Converte a imagem fornecida para uma imagem preto e branco utilizando o algoritmo de dithering Floyd-Steinberg, que distribui o erro garantindo uma textura de meio-tom (ideal para impressoras térmicas).
bluetooth_pos_printer_utils package
documentation
core/halftone
Halftone class
halftone library